@@ -16,6 +16,8 @@ rm -f install-sh
 rm -f ltmain.sh
 rm -f Makefile.in
 rm -f missing
+rm -f deb/Makefile.in
+rm -f deb/control
 rm -f src/Makefile.in
 rm -f src/biblioteca/Makefile.in
 rm -f src/headers/Makefile.in
