@@ -185,8 +185,8 @@ int pds_cell_string_all_fprintf(FILE* fd,const PdsCellString *C)
 	return TRUE;
 }
 
-/** \fn int pds_cell_string_save(FILE* fd,const PdsCellString *C)
- *  \brief Imprime en el descriptor de fichero los datos del arreglo de células 
+/** \fn int pds_cell_string_save(const char* pathname,const PdsCellString *C)
+ *  \brief Imprime en el archivo los datos del arreglo de células 
  *  de tipo puntero PdsCellString. Escribe un dato por cada linea.
  *  \param[in] pathname La dirección de fichero sobre el cual escribir.
  *  \param[in] C El arreglo de células a escribir.
@@ -387,6 +387,88 @@ int pds_cell_string_get_ncell(const PdsCellString *C)
 }
 
 
+/** \fn char * pds_cell_string_joint(const PdsCellString *C)
+ *  \brief Retorna una nueva cadena de texto con los valores de la PdsCellString 
+ *  concatenados.
+ *  \param[in] C El arreglo de células a concatenar.
+ *  \return Retorna una nueva cadena de texto con os valores de la PdsCellString 
+ *  concatenados. O NULL en caso de error, o C NULL.
+ *  \see pds_strcat_cell_string()
+ *  \ingroup PdsCellStringGroup
+ */
+char * pds_cell_string_joint(const PdsCellString *C)
+{
+    int i,len;
+    char *string=NULL;
+    char *string_ptr=NULL;
+
+	if(C==NULL) return NULL;
+
+    len=0;
+    for(i=0;i<C->Ncell;i++)
+    {
+        len=len+strlen(C->data[i]);
+    }
+
+    string=(char *)calloc(len+1,sizeof(char));
+
+    string_ptr=string;
+
+    for(i=0;i<C->Ncell;i++)
+    {
+        strcpy(string_ptr,C->data[i]);
+        string_ptr=string_ptr + strlen(C->data[i]);
+    }
+
+    return string;
+}
+
+
+/** \fn char * pds_cell_string_joint_with_end(const PdsCellString *C, char d)
+ *  \brief Retorna una nueva cadena de texto con los valores de la PdsCellString 
+ *  concatenados agregando el delimiatador d al final de cada celula.
+ *
+ *  "str1"<b>d</b>"str2"<b>d</b> ... <b>d</b>"strN"<b>d</b>
+ *
+ *  \param[in] C El arreglo de células a concatenar.
+ *  \param[in] d El delimitador de final de celula. Si d==0 no agrega delimitador.
+ *  \return Retorna una nueva cadena de texto con os valores de la PdsCellString 
+ *  concatenados. O NULL en caso de error, o C NULL.
+ *  \see pds_strcat_cell_string()
+ *  \ingroup PdsCellStringGroup
+ */
+char * pds_cell_string_joint_with_end(const PdsCellString *C,char d)
+{
+    int i,len;
+    char *string=NULL;
+    char *string_ptr=NULL;
+
+	if(C==NULL) return NULL;
+
+    len=0;
+    for(i=0;i<C->Ncell;i++)
+    {
+        len=len+strlen(C->data[i]);
+        if(d!=0)    len=len+1;
+    }
+
+    string=(char *)calloc(len+1,sizeof(char));
+
+    string_ptr=string;
+
+    for(i=0;i<C->Ncell;i++)
+    {
+        strcpy(string_ptr,C->data[i]);
+        string_ptr=string_ptr + strlen(C->data[i]);
+        if(d!=0)
+        {
+            string_ptr[0]=d;
+            string_ptr=string_ptr + 1;
+        }
+    }
+
+    return string;
+}
 
 /** \fn int pds_cell_string_get_last_empty(const PdsCellString *C)
  *  \brief Retorna el id de la última célula libre (osea con NULL).
@@ -640,7 +722,7 @@ int pds_cell_string_findci_and_add(PdsCellString *C,const char* string_data)
 }
 
 
-/** \fn int pds_cell_string_find_and_remove(const PdsCellString *C,const char *str)
+/** \fn int pds_cell_string_find_and_remove(PdsCellString *C,const char *str)
  *  \brief Procura todas las células con cadenas igual a str y las remueve.
  *  \param[in,out] C El arreglo de células a analizar.
  *  \param[in] str La cadena a buscar.
@@ -674,7 +756,7 @@ int pds_cell_string_find_and_remove(PdsCellString *C,const char *str)
 }
 
 
-/** \fn int pds_cell_string_findci_and_remove(const PdsCellString *C,const char *str)
+/** \fn int pds_cell_string_findci_and_remove(PdsCellString *C,const char *str)
  *  \brief Procura todas las células con cadenas igual a str y las remueve.
  *  \param[in,out] C El arreglo de células a analizar.
  *  La función es case-insensitive.
