@@ -407,6 +407,28 @@ PdsCellString *pds_get_all_files_new(const char *dirpath,   const char* pattern_
     return FileCell;
 }
 
+/** \fn int pds_cat(const char* filepath)
+ *  \brief Imprime en pantalla el contenido de un archivo de texto apuntado por
+ *   filepath.
+ *
+ *  \param[in] filepath Ruta del fichero a analizar. 
+ *  \return Retorna TRUE si todo fue bien o FALSE en el caso contrario.
+ *  \ingroup PdsFilesFuncGroup
+ */
+int pds_cat(const char* filepath)
+{
+    FILE *fd=NULL;
+    char c;
+
+    fd=fopen(filepath,"r");
+    if(fd==NULL)    return FALSE;
+
+    while ((c = getc(fd)) != EOF)   putchar(c);
+
+    fclose(fd);
+
+    return TRUE;
+}
 
 /** \fn char *pds_get_realpath(const char* filepath)
  *  \brief Expande todos los enlaces simbolicos y resuleve referencia a /./,
@@ -755,6 +777,50 @@ char* pds_get_absolute_programpath(void)
 }
 
 
+/** \fn PdsCellString *pds_get_all_filename_extensions_in_cell(const PdsCellString *FileCell)
+ *  \brief Retorna una estructura PdsCellString con un arreglo de células con las 
+ *  extenciones de archivos en el PdsCellString. 
+ *  A partir de aquí pueden ser leidos los datos con la función pds_cell_string_read().
+ *  \param[in] FileCell Celula donde se buscará etensiones.
+ *  \return Retorna una estructura PdsCellString con un arreglo de células con 
+ *  los nombres de todas las extenciones de archivos. En caso de no existir extensiones
+ *  retorna una estructura vacia, en caso de error retorna NULL. Si FileCell==NULL
+ *  se retorna NULL.
+ *  \ingroup PdsFilesFuncGroup
+ */
+PdsCellString *pds_get_all_filename_extensions_in_cell(const PdsCellString *FileCell)
+{
+    PdsCellString *ExtCell=NULL;
+
+    char *strPtr=NULL;
+    int i,dat;
+
+    if(FileCell==NULL)  return NULL;
+
+    
+    ExtCell=pds_cell_string_new(0);
+    if(ExtCell==NULL)   {return NULL;}
+
+    for(i=0;i<FileCell->Ncell;i++)
+    {
+        strPtr=pds_get_filename_extension(FileCell->data[i]);
+        
+        if(strPtr!=NULL)
+        if(strlen(strPtr)>0)
+        if(pds_cell_string_find(ExtCell,strPtr)<0)
+        {
+            dat=pds_cell_string_add(ExtCell,strPtr);
+            if(dat==FALSE)
+            {
+                pds_cell_string_free(ExtCell);
+                return NULL;
+            }
+        }
+    }
+
+    return ExtCell;
+}
+
 /** \fn PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char* pattern_include,const char* pattern_exclude,const char* file_pattern_include,const char* file_pattern_exclude)
  *  \brief Retorna una estructura PdsCellString con un arreglo de células con las 
  *  extenciones de archivos en el directorio. No son buscados archivos en los directorios simbólicos.
@@ -765,7 +831,9 @@ char* pds_get_absolute_programpath(void)
  *  \param[in] file_pattern_include Patrón de archivos a incluir solamente.
  *  \param[in] file_pattern_exclude Patrón de archivos a excluir.
  *  \return Retorna una estructura PdsCellString con un arreglo de células con 
- *  los nombres de todas las extenciones de archivos.
+ *  los nombres de todas las extenciones de archivos. En caso de error retorna NULL.
+ *  Si dirpath==NULL se retorna NULL. En caso de no existir extensiones
+ *  retorna una estructura vacia
  *  \ingroup PdsFilesFuncGroup
  */
 PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char* pattern_include,
@@ -783,37 +851,11 @@ PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char
     FileCell=pds_get_all_files_new(dirpath,pattern_include,pattern_exclude,file_pattern_include,file_pattern_exclude);
     if(FileCell==NULL)  return NULL;
 
-    
-    ExtCell=pds_cell_string_new(0);
-    if(ExtCell==NULL)   {pds_cell_string_free(FileCell);return NULL;}
-
-    for(i=0;i<FileCell->Ncell;i++)
-    {
-        strPtr=pds_get_filename_extension(FileCell->data[i]);
-        
-        if(strPtr!=NULL)
-        if(strlen(strPtr)>0)
-        if(pds_cell_string_find(ExtCell,strPtr)<0)
-        {
-            dat=pds_cell_string_add(ExtCell,strPtr);
-            if(dat==FALSE)
-            {
-                pds_cell_string_free(FileCell);
-                pds_cell_string_free(ExtCell);
-                return NULL;
-            }
-        }
-    }
-
+    ExtCell=pds_get_all_filename_extensions_in_cell(FileCell);
+    if(ExtCell==NULL)  return NULL;
 
     pds_cell_string_free(FileCell);
 
-    if(pds_cell_string_get_last_empty(ExtCell)==0)
-    {
-        pds_cell_string_free(ExtCell);
-        return NULL;
-    }
-
     return ExtCell;
 }
 
@@ -923,6 +965,8 @@ char *pds_read_line(FILE *fd)
 /** \fn char *pds_get_filedata_string(const char *pathname,const char* pattern)
  *  \brief La funcion analiza linea por linea el archivo y retorna
  *  el texto despues de el primer patrón pattern encontrado.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
@@ -937,11 +981,20 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
     char *LINE=NULL;
     char *DATA=NULL;
     int N,Nl,i;
+    char *PATTERN=NULL;
 
     if(pathname==NULL)  return NULL;
     if(pattern ==NULL)  return NULL;
 
-    N=strlen(pattern);
+
+    PATTERN=(char*)calloc(strlen(pattern)+1,sizeof(char));
+    if(PATTERN==NULL)   return NULL;
+    strcpy(PATTERN,pattern);
+    pds_string_clean_beginning(PATTERN,' ');
+    pds_string_clean_ending(PATTERN,' ');
+
+    N=strlen(PATTERN);
+    
 
     fd=fopen(pathname,"r");
     if(fd==NULL)
@@ -957,15 +1010,19 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
         LINE=pds_read_line(fd);
         if(LINE!=NULL)
         {
+
+            pds_string_clean_beginning (LINE,' ');
+
             Nl=strlen(LINE);
             if(Nl>=N)
-            if(strncmp(pattern,LINE,N)==0)
+            if(strncmp(PATTERN,LINE,N)==0)
             {
                 DATA=(char*)calloc(Nl-N+1,sizeof(char));
                 if(DATA==NULL)
                 {
                     fprintf(stderr,"ERROR while alloc memory.\n");
                     fclose(fd);
+                    free(PATTERN);
                     free(LINE);
                     return NULL;
                 }
@@ -981,17 +1038,79 @@ char *pds_get_filedata_string(const char *pathname,const char* pattern)
         DATA=(char*)calloc(1,sizeof(char));
     }
 
+    pds_string_clean_beginning (DATA,' ');
+    pds_string_clean_ending (DATA,'\n');
+    pds_string_clean_ending (DATA,' ');
+
     fclose(fd);
     free(LINE);
+    free(PATTERN);
 
     return DATA;
 }
 
+/** \fn int pds_get_filedata_int(const char *pathname,const char* pattern)
+ *  \brief La funcion analiza linea por linea el archivo y retorna
+ *  el valor int despues de el primer patrón pattern encontrado.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
+ *
+ *  \param[in] pathname Fichero de texto a analizar.
+ *  \param[in] pattern Patrón a buscar.
+ *  \return Retorna el valor en int con el dato encontrado.
+ *  En caso de error es retornado zero.
+ *  \ingroup PdsFilesFuncGroup
+ */
+int pds_get_filedata_int(const char *pathname,const char* pattern)
+{
+    char *str=NULL;
+    int d;
+
+    str=pds_get_filedata_string(pathname,pattern);
+    if(str==NULL)    return 0;
+
+    d=atoi(str);
+
+    free(str);
+
+    return d;
+}
+
+/** \fn int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat)
+ *  \brief La funcion analiza linea por linea el archivo y retorna
+ *  TRUE si el valor despues de el primer patrón pattern encontrado es dat.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
+ *
+ *  \param[in] pathname Fichero de texto a analizar.
+ *  \param[in] pattern Patrón a buscar.
+ *  \param[in] dat Dato a comparar.
+ *  \return Retorna TRUE si el valor dat es encontrado despues del primer 
+ *  patrón pattern. En caso de error es retornado FALSE.
+ *  \ingroup PdsFilesFuncGroup
+ */
+int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat)
+{
+    char *str=NULL;
+    int d;
+
+    str=pds_get_filedata_string(pathname,pattern);
+    if(str==NULL)    return 0;
+
+    if(strcmp(dat,str)==0)  d=TRUE;
+    else                    d=FALSE;
+
+    free(str);
+
+    return d;
+}
 
 /** \fn PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  el texto despues de el primer patrón pattern encontrado, Pero estos datos son
+ *  el texto despues de el primer patrón pattern encontrado, pero estos datos son
  *  separados usando algunos de los separadores usados en separator y ordenandos en una PdsCellString.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
@@ -1006,6 +1125,7 @@ PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pat
 {
     char *DATA=NULL;
     PdsCellString *CELL=NULL;
+    int i;
     
     if(pathname==NULL)  return NULL;
     if(pattern==NULL)   return NULL;
@@ -1016,6 +1136,11 @@ PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pat
     if(separator!=NULL) CELL=pds_strsep_cell_string (DATA,separator);
     else                CELL=pds_strsep_cell_string (DATA,"");
 
+    for(i=0;i<CELL->Ncell;i++)
+    {
+        pds_string_clean_beginning(CELL->data[i],' ');
+        pds_string_clean_ending(CELL->data[i],' ');
+    }
 
     free(DATA);
     return CELL;
@@ -1088,6 +1213,7 @@ long pds_get_file_size(const char *path)
 
 /** \fn long pds_get_number_of_chars(const char *path)
  *  \brief Retorna el número de caracteres de un archivo.
+ *  Se asume que es un archivo de texto.
  *
  *  \param[in] path Dirección de archivo a testar.
  *  \return Retorna el número de caracteres de un archivo
