@@ -119,7 +119,7 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
 
 //@}
 
-/** @name pds_get_filedata_<methods>
+/** @name pds_get_filedata_<search_pattern_methods>
  *  Funciones con buquedas de datos en ficheros.
  *
  * @{
@@ -128,6 +128,8 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
 /** \fn char *pds_get_filedata_string(const char *pathname,const char* pattern)
  *  \brief La funcion analiza linea por linea el archivo y retorna
  *  el texto despues de el primer patrón pattern encontrado.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
@@ -138,11 +140,42 @@ PdsCellString *pds_get_arquives_new(const char *dirpath,ArqType Type,const char*
  */
 char *pds_get_filedata_string(const char *pathname,const char* pattern);
 
+/** \fn int pds_get_filedata_int(const char *pathname,const char* pattern)
+ *  \brief La funcion analiza linea por linea el archivo y retorna
+ *  el valor int despues de el primer patrón pattern encontrado.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
+ *
+ *  \param[in] pathname Fichero de texto a analizar.
+ *  \param[in] pattern Patrón a buscar.
+ *  \return Retorna el valor en int con el dato encontrado.
+ *  En caso de error es retornado zero.
+ *  \ingroup PdsFilesFuncGroup
+ */
+int pds_get_filedata_int(const char *pathname,const char* pattern);
+
+/** \fn int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat)
+ *  \brief La funcion analiza linea por linea el archivo y retorna
+ *  TRUE si el valor despues de el primer patrón pattern encontrado es dat.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
+ *
+ *  \param[in] pathname Fichero de texto a analizar.
+ *  \param[in] pattern Patrón a buscar.
+ *  \param[in] dat Dato a comparar.
+ *  \return Retorna TRUE si el valor dat es encontrado despues del primer 
+ *  patrón pattern. En caso de error es retornado FALSE.
+ *  \ingroup PdsFilesFuncGroup
+ */
+int pds_get_filedata_strcmp(const char *pathname,const char* pattern,const char* dat);
+
 
 /** \fn PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pattern,const char *separator)
  *  \brief La funcion analiza linea por linea el archivo y retorna
- *  el texto despues de el primer patrón pattern encontrado, Pero estos datos son
+ *  el texto despues de el primer patrón pattern encontrado, pero estos datos son
  *  separados usando algunos de los separadores usados en separator y ordenandos en una PdsCellString.
+ *  Son desconsiderados en la comparación los espacios ' ' iniciales y el salto
+ *  de linea final.
  *
  *  \param[in] pathname Fichero de texto a analizar.
  *  \param[in] pattern Patrón a buscar.
@@ -157,7 +190,7 @@ PdsCellString *pds_get_filedata_cell_string(const char *pathname,const char* pat
 
 //@}
 
-/** @name pds_get_all_<methods>
+/** @name pds_get_all_<search_file_methods>
  *  Funciones con buquedas recursivas.
  *
  * @{
@@ -199,6 +232,20 @@ PdsCellString *pds_get_all_files_new(const char *dirpath,   const char* pattern_
                                                             const char* file_pattern_exclude);
 
 
+/** \fn PdsCellString *pds_get_all_filename_extensions_in_cell(const PdsCellString *FileCell)
+ *  \brief Retorna una estructura PdsCellString con un arreglo de células con las 
+ *  extenciones de archivos en el PdsCellString. 
+ *  A partir de aquí pueden ser leidos los datos con la función pds_cell_string_read().
+ *  \param[in] FileCell Celula donde se buscará etensiones.
+ *  \return Retorna una estructura PdsCellString con un arreglo de células con 
+ *  los nombres de todas las extenciones de archivos. En caso de no existir extensiones
+ *  retorna una estructura vacia, en caso de error retorna NULL. Si FileCell==NULL
+ *  se retorna NULL.
+ *  \ingroup PdsFilesFuncGroup
+ */
+PdsCellString *pds_get_all_filename_extensions_in_cell(const PdsCellString *FileCell);
+
+
 /** \fn PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char* pattern_include,const char* pattern_exclude,const char* file_pattern_include,const char* file_pattern_exclude)
  *  \brief Retorna una estructura PdsCellString con un arreglo de células con las 
  *  extenciones de archivos en el directorio. No son buscados archivos en los directorios simbólicos.
@@ -227,6 +274,16 @@ PdsCellString *pds_get_all_filename_extensions(const char *dirpath,   const char
  */
 
 
+/** \fn int pds_cat(const char* filepath)
+ *  \brief Imprime en pantalla el contenido de un archivo de texto apuntado por
+ *   filepath.
+ *
+ *  \param[in] filepath Ruta del fichero a analizar. 
+ *  \return Retorna TRUE si todo fue bien o FALSE en el caso contrario.
+ *  \ingroup PdsFilesFuncGroup
+ */
+int pds_cat(const char* filepath);
+
 /** \fn char *pds_get_realpath(const char* filepath)
  *  \brief Expande todos los enlaces simbolicos y resuleve referencia a /./,
  *  /../ y caracteres extras '/'  en filepath, asi es producido un pathname 
@@ -445,6 +502,7 @@ long pds_get_file_size(const char *path);
 
 /** \fn long pds_get_number_of_chars(const char *path)
  *  \brief Retorna el número de caracteres de un archivo.
+ *  Se asume que es un archivo de texto.
  *
  *  \param[in] path Dirección de archivo a testar.
  *  \return Retorna el número de caracteres de un archivo
